## Moildev SDK

Moildev Library is a collection of functions support python to developments fisheye image applications. This Version just for **Linux OS** only. For more information, visit this [documentation](https://github.com/MoilOrg/moildev)

### Installation

you can install this Library via PIP:

```
>> pip install moildev
```

If you don't want to install the library via PIP, you can download from [GitHub Repository](https://github.com/MoilOrg/moildev) and move the package Moildev to your working directory.

### How to Import 

You can Import library like showing below:

```
>> import Moildev

# test is this library work or not
>> Moildev.test()

# check version
>> Moildev.version()
```

To create the object from Moildev, you have to provide the parameter. The camera parameter is the result from camera calibration process by MOIL laboratory that stored on **.json** file.

```
# using single  camera parameter file
>> moildev = Moildev.Moildev("Camera_Parameter_Path")

# using Muitiple  camera parameter file
>> moildev = Moildev.Moildev("Camera_Parameter_Path", "camera_name")
```

- **Camera_Parameter_Path** : The path of the *(**.json**)* file that stored the camera parameter from calibration result.

- **camera_name** = Change to the keyword of name camera available on camera parameter file.



#### Calculate alha beta

This function will return the value of alpha beta from specific coordinate image given. 

```
>> alpha, beta = moildev(coordinate_x, coordinate_y)
```

- **coordinate_x** = The coordinate target point in x axis

- **coordinate_y** = The coordinate target point in y axis



#### Get image center x

Return center image in X axis.

```
>> icx = moildev.getIcx()
```

#### Get image center y

Return center image in Y axis.

```
>> icy = moildev.getIcy()
```

#### Get image width

Return the image width

```
>> im_width = moildev.getImageWidth()
```

#### Get image height

Return the image height

```
>> im_height = moildev.getImageHeight()
```

#### Create maps for Anypoint View

Generate a pair of X-Y Maps for the specified alpha, beta and zoom, the result X-Y Maps can be used later to remap the original fish-eye image to create anypoint views. 

```
>> map_x, map_y = moildev.getAnypointMaps(alpha, beta, zoom, mode=1)
```

- **alpha**: the value of alpha
- **beta**: the value of beta
- **zoom**: decimal zoom factor, normally 1..12
- **mode** = selection anypoint mode(1 or 2), by default if will be mode 1



#### Anypoint

this function will generate anypoint view imagewith 2 mode selection. for mode 1, the result will have rotation in beta degree rotation around the Z-axis(roll) after alphaOffset degree rotation around the X-axis(pitch). for mode 2, The result rotation is theta_Y degree rotation around the Y-axis(yaw) after theta_X degree rotation around the X-axis(pitch).

```
>> anypoint_image = moildev.anypoint(image, alpha, beta, zoom, mode=1)
```

- **image**: source image
- **alpha**: the value of alpha
- **beta**: the value of beta
- **zoom**: decimal zoom factor, normally 1..12
- **mode**: mode anypoint view (by default it will be mode 1)



#### Create panorama maps

To generate a pair of X-Y Maps for alpha within 0..alpha_max degree, the result X-Y Maps can be used later to generate a panorama image from the original fish-eye image. 

```
>> map_x, map_y = moildev.getPanoramaMaps(alpha_min, alpha_max)
```

- **alpha_min** = the minimum alpha (>10 because 0-10 degree its no have much information)
- **alpha_max** = the maximum of alpha. The recommended vaule is half of camera FOV.



#### Panorama

The panorama image centered at the 3D direction with alpha = iC_alpha_degree and beta = iC_beta_degree.

```
>> panorama_image = moildev.panorama(image, alpha_min, alpha_max)
```

- **image** = the original image  
- **alpha_min** = the minimum alpha 
- **alpha_max** : max of alpha. The recommended vaule is half of camera FOV. 



#### Reverse View

This will process image to change the optical point of Fisheye image.

```
>> reverse_image = moildev.reverseImage(image, alpha_max,alpha, beta)
```

- **image** = The original fisheye image
- **alpha_max** = max of alpha. The recommended value is half of camera FOV. 
- **alpha** = the value of alpha
- **beta** = the value of alpha



### [About us](https://oil-mcut.educationhost.cloud/)

